@@ -31,6 +31,10 @@
 
 #include "caja-column-utilities.h"
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+#define gtk_vbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_VERTICAL,Y)
+#endif
+
 struct _CajaColumnChooserDetails
 {
     GtkTreeView *view;
