@@ -33,8 +33,6 @@
 #include <eel/eel-gtk-macros.h>
 #include <gtk/gtk.h>
 
-#include <src/glibcompat.h> /* for g_list_free_full */
-
 struct CajaMergedDirectoryDetails
 {
     GList *directories;
@@ -71,7 +69,7 @@ enum
     LAST_SIGNAL
 };
 
-static guint signals[LAST_SIGNAL];
+static guint signals[LAST_SIGNAL] = { 0 };
 
 G_DEFINE_TYPE (CajaMergedDirectory, caja_merged_directory,
                CAJA_TYPE_DIRECTORY);
