@@ -39,6 +39,11 @@
 #define sure_string(s)                    ((const char *)((s)!=NULL?(s):""))
 #define DESKTOP_ENTRY_GROUP		  "Desktop Entry"
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+#define gtk_hbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_HORIZONTAL,Y)
+#define gtk_vbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_VERTICAL,Y)
+#endif
+
 struct _CajaOpenWithDialogDetails
 {
     GAppInfo *selected_app_info;
@@ -852,7 +857,11 @@ caja_open_with_dialog_init (CajaOpenWithDialog *dialog)
     gtk_box_pack_start (GTK_BOX (vbox), vbox2, TRUE, TRUE, 0);
 
     dialog->details->label = gtk_label_new ("");
+#if GTK_CHECK_VERSION (3, 14, 0)
+    gtk_widget_set_halign (dialog->details->label, GTK_ALIGN_START);
+#else
     gtk_misc_set_alignment (GTK_MISC (dialog->details->label), 0.0, 0.5);
+#endif
     gtk_label_set_line_wrap (GTK_LABEL (dialog->details->label), TRUE);
     gtk_box_pack_start (GTK_BOX (vbox2), dialog->details->label,
                         FALSE, FALSE, 0);
@@ -875,7 +884,11 @@ caja_open_with_dialog_init (CajaOpenWithDialog *dialog)
     gtk_box_pack_start (GTK_BOX (vbox2), scrolled_window, TRUE, TRUE, 0);
 
     dialog->details->desc_label = gtk_label_new (_("Select an application to view its description."));
+#if GTK_CHECK_VERSION (3, 14, 0)
+    gtk_widget_set_halign (dialog->details->desc_label, GTK_ALIGN_START);
+#else
     gtk_misc_set_alignment (GTK_MISC (dialog->details->desc_label), 0.0, 0.5);
+#endif
     gtk_label_set_justify (GTK_LABEL (dialog->details->desc_label), GTK_JUSTIFY_LEFT);
     gtk_label_set_line_wrap (GTK_LABEL (dialog->details->desc_label), TRUE);
     gtk_label_set_single_line_mode (GTK_LABEL (dialog->details->desc_label), FALSE);
