@@ -46,6 +46,11 @@ enum
 
 #define SIGNAL_DELAY_MSEC 100
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+#define gtk_hbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_HORIZONTAL,Y)
+#define gtk_vbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_VERTICAL,Y)
+#endif
+
 static guint signals[LAST_SIGNAL] = { 0 };
 
 struct _CajaProgressInfo
@@ -370,7 +375,11 @@ progress_widget_new (CajaProgressInfo *info)
     gtk_widget_set_size_request (label, 500, -1);
     gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
     gtk_label_set_line_wrap_mode (GTK_LABEL (label), PANGO_WRAP_WORD_CHAR);
+#if GTK_CHECK_VERSION (3, 14, 0)
+    gtk_widget_set_halign (label, GTK_ALIGN_START);
+#else
     gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+#endif
     gtk_box_pack_start (GTK_BOX (vbox),
                         label,
                         TRUE, FALSE,
@@ -408,7 +417,11 @@ progress_widget_new (CajaProgressInfo *info)
                         0);
 
     label = gtk_label_new ("details");
+#if GTK_CHECK_VERSION (3, 14, 0)
+    gtk_widget_set_halign (label, GTK_ALIGN_START);
+#else
     gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+#endif
     gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
     gtk_box_pack_start (GTK_BOX (vbox),
                         label,
