@@ -40,6 +40,11 @@
 #include <libcaja-private/caja-global-preferences.h>
 #include <libcaja-private/caja-icon-names.h>
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+#define gtk_hbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_HORIZONTAL,Y)
+#define gtk_vbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_VERTICAL,Y)
+#endif
+
 /* TODO:
  * - name entry + pre-fill
  * - NetworkManager integration
@@ -116,6 +121,7 @@ enum
 /* Remember to fill in descriptions below */
 static struct MethodInfo methods[] =
 {
+    { "afp", SHOW_SHARE | SHOW_USER, 548 },
     /* FIXME: we need to alias ssh to sftp */
     { "sftp",  SHOW_PORT | SHOW_USER, 22 },
     { "ftp",  SHOW_PORT | SHOW_USER, 21 },
@@ -145,8 +151,10 @@ get_method_description (struct MethodInfo *meth)
     } else if (strcmp (meth->scheme, "davs") == 0) {
         return _("Secure WebDAV (HTTPS)");
 
-        /* No descriptive text */
+    } else if (strcmp (meth->scheme, "afp") == 0) {
+        return _("Apple Filing Protocol (AFP)");
     } else {
+        /* No descriptive text */
         return meth->scheme;
     }
 }
@@ -540,12 +548,13 @@ connect_dialog_connect_to_server (CajaConnectServerDialog *dialog)
     domain = NULL;
     folder = NULL;
 
-    /* FTP special case */
     if (meth->flags & IS_ANONYMOUS) {
+        /* FTP special case */
     	user = g_strdup ("anonymous");
 
-        /* SMB special case */
-    } else if (strcmp (meth->scheme, "smb") == 0) {
+    } else if ((strcmp (meth->scheme, "smb") == 0) ||
+		(strcmp (meth->scheme, "afp") == 0)){
+		/* SMB/AFP special case */
 		g_free (initial_path);
 
     	t = gtk_editable_get_chars (GTK_EDITABLE (dialog->details->share_entry), 0, -1);
@@ -870,7 +879,11 @@ caja_connect_server_dialog_init (CajaConnectServerDialog *dialog)
     str = g_strdup_printf ("<b>%s</b>", _("Server Details"));
     gtk_label_set_markup (GTK_LABEL (label), str);
     g_free (str);
+#if GTK_CHECK_VERSION (3, 14, 0)
+    gtk_widget_set_halign (label, GTK_ALIGN_START);
+#else
     gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+#endif
     gtk_box_pack_start (GTK_BOX (content_area), label, FALSE, FALSE, 6);
     gtk_widget_show (label);
 
@@ -889,7 +902,11 @@ caja_connect_server_dialog_init (CajaConnectServerDialog *dialog)
 
     /* first row: server entry + port spinbutton */
     label = gtk_label_new_with_mnemonic (_("_Server:"));
+#if GTK_CHECK_VERSION (3, 14, 0)
+    gtk_widget_set_halign (label, GTK_ALIGN_START);
+#else
     gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+#endif
     gtk_table_attach (GTK_TABLE (table), label,
     		  0, 1,
     		  0, 1,
@@ -911,7 +928,11 @@ caja_connect_server_dialog_init (CajaConnectServerDialog *dialog)
 
     /* port */
     label = gtk_label_new_with_mnemonic (_("_Port:"));
+#if GTK_CHECK_VERSION (3, 14, 0)
+    gtk_widget_set_halign (label, GTK_ALIGN_START);
+#else
     gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+#endif
     gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
     gtk_widget_show (label);
 
@@ -929,7 +950,11 @@ caja_connect_server_dialog_init (CajaConnectServerDialog *dialog)
 
     /* second row: type combobox */
     label = gtk_label_new (_("Type:"));
+#if GTK_CHECK_VERSION (3, 14, 0)
+    gtk_widget_set_halign (label, GTK_ALIGN_START);
+#else
     gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+#endif
     gtk_table_attach (GTK_TABLE (table), label,
     		  0, 1,
     		  1, 2,
@@ -1007,7 +1032,11 @@ caja_connect_server_dialog_init (CajaConnectServerDialog *dialog)
 
     /* third row: share entry */
     label = gtk_label_new (_("Share:"));
+#if GTK_CHECK_VERSION (3, 14, 0)
+    gtk_widget_set_halign (label, GTK_ALIGN_START);
+#else
     gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+#endif
     gtk_table_attach (GTK_TABLE (table), label,
     		  0, 1,
     		  2, 3,
@@ -1024,7 +1053,11 @@ caja_connect_server_dialog_init (CajaConnectServerDialog *dialog)
 
     /* fourth row: folder entry */
     label = gtk_label_new (_("Folder:"));
+#if GTK_CHECK_VERSION (3, 14, 0)
+    gtk_widget_set_halign (label, GTK_ALIGN_START);
+#else
     gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+#endif
     gtk_table_attach (GTK_TABLE (table), label,
     		  0, 1,
     		  3, 4,
@@ -1044,7 +1077,11 @@ caja_connect_server_dialog_init (CajaConnectServerDialog *dialog)
     str = g_strdup_printf ("<b>%s</b>", _("User Details"));
     gtk_label_set_markup (GTK_LABEL (label), str);
     g_free (str);
+#if GTK_CHECK_VERSION (3, 14, 0)
+    gtk_widget_set_halign (label, GTK_ALIGN_START);
+#else
     gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+#endif
     gtk_box_pack_start (GTK_BOX (content_area), label, FALSE, FALSE, 6);
 
     /* user details alignment */
@@ -1062,7 +1099,11 @@ caja_connect_server_dialog_init (CajaConnectServerDialog *dialog)
 
     /* first row: domain entry */
     label = gtk_label_new (_("Domain Name:"));
+#if GTK_CHECK_VERSION (3, 14, 0)
+    gtk_widget_set_halign (label, GTK_ALIGN_START);
+#else
     gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+#endif
     gtk_table_attach (GTK_TABLE (table), label,
     		  0, 1,
     		  0, 1,
@@ -1079,7 +1120,11 @@ caja_connect_server_dialog_init (CajaConnectServerDialog *dialog)
 
     /* second row: username entry */
     label = gtk_label_new (_("User Name:"));
+#if GTK_CHECK_VERSION (3, 14, 0)
+    gtk_widget_set_halign (label, GTK_ALIGN_START);
+#else
     gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+#endif
     gtk_table_attach (GTK_TABLE (table), label,
     		  0, 1,
     		  1, 2,
@@ -1096,7 +1141,11 @@ caja_connect_server_dialog_init (CajaConnectServerDialog *dialog)
 
 	/* third row: password entry */
 	label = gtk_label_new (_("Password:"));
-    gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+#if GTK_CHECK_VERSION (3, 14, 0)
+	gtk_widget_set_halign (label, GTK_ALIGN_START);
+#else
+	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+#endif
 	gtk_table_attach (GTK_TABLE (table), label,
 			  0, 1,
 			  2, 3,
