@@ -49,8 +49,6 @@
 #include <libcaja-private/caja-sidebar-provider.h>
 #include <libcaja-private/caja-module.h>
 
-#include "glibcompat.h" /* for g_list_free_full */
-
 struct CajaInformationPanelDetails
 {
     GtkVBox *container;
@@ -102,7 +100,7 @@ enum
     LAST_SIGNAL
 };
 
-static guint signals[LAST_SIGNAL];
+static guint signals[LAST_SIGNAL] = { 0 };
 
 /* drag and drop definitions */
 
