@@ -45,6 +45,10 @@ G_DEFINE_TYPE (CajaNavigationWindowPane,
                CAJA_TYPE_WINDOW_PANE)
 #define parent_class caja_navigation_window_pane_parent_class
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+#define gtk_hbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_HORIZONTAL,Y)
+#define gtk_vbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_VERTICAL,Y)
+#endif
 
 static void
 real_set_active (CajaWindowPane *pane, gboolean is_active)
