@@ -36,6 +36,10 @@
 
 #define MAIN_GROUP "Desktop Entry"
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+#define gtk_vbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_VERTICAL,Y)
+#endif
+
 typedef struct ItemEntry
 {
     const char *field;
@@ -342,7 +346,11 @@ build_table (GtkWidget *container,
         label = gtk_label_new (label_text);
         gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
         g_free (label_text);
+#if GTK_CHECK_VERSION (3, 14, 0)
+        gtk_widget_set_halign (label, GTK_ALIGN_START);
+#else
         gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+#endif
         gtk_size_group_add_widget (label_size_group, label);
 
         entry = gtk_entry_new ();
